@@ -1,13 +1,29 @@
 import pycountry
+import numpy as np
+import hashlib
+import more_itertools as mit
+from datetime import datetime
+from sourceRank.helper.settings import logger, default_field
+from restcountries import RestCountryApiV2 as rapi
+from tldextract import TLDExtract
+from tldextract.tldextract import ExtractResult
 from fuzzywuzzy import fuzz, process
 from scipy import stats
 from dateutil.parser import parse
-import numpy as np
-from datetime import datetime
-from sourceRank.helper.settings import logger, default_field
-import hashlib
-import more_itertools as mit
-from restcountries import RestCountryApiV2 as rapi
+
+
+def parse_url(url: str) -> ExtractResult:
+    tld_res: ExtractResult = ExtractResult(
+        domain="", subdomain="", suffix="")
+    try:
+        tld_extract_obj: TLDExtract = TLDExtract(
+            include_psl_private_domains=True)
+        tld_res: ExtractResult = tld_extract_obj(
+            url=url, include_psl_private_domains=True)
+
+    except Exception as e:
+        logger.error(e)
+    return tld_res
 
 
 def get_country_name_by_code(country_code: str) -> str:
@@ -65,13 +81,17 @@ def get_datetime_from_str(str_datetime: str, target_format: str = '%Y-%m-%d %H:%
 
 def get_str_datetime_from_non_formatted_str(str_datetime: str,
                                             target_format: str = '%Y-%m-%d %H:%M:%S') -> str:
-    if len(str_datetime) > 1:
-        origin_datetime_obj: datetime = parse(str_datetime)
-    else:
-        # default date
-        origin_datetime_obj: datetime = datetime.now()
+    target_datetime_obj: str = "1996-01-01 00:00:00"
+    try:
+        if len(str_datetime) > 1:
+            origin_datetime_obj: datetime = parse(str_datetime)
+        else:
+            # default date
+            origin_datetime_obj: datetime = datetime.now()
 
-    target_datetime_obj: str = origin_datetime_obj.strftime(target_format)
+        target_datetime_obj: str = origin_datetime_obj.strftime(target_format)
+    except Exception as e:
+        pass
 
     return target_datetime_obj
 
@@ -192,4 +212,8 @@ def parameterized_ReLU(x, alpha=0.01) -> float:
             y: float = x
     except Exception as e:
         logger.error(e)
-    return y
\ No newline at end of file
+    return y
+
+
+def relevance_mapping(x: float, alpha: float = .20) -> float:
+    return 1 - (1/(1 + alpha * x))
\ No newline at end of file
